==> kphotoalbum_4.2.orig.tar.bz2: kphotoalbum-4.2/ImageManager/ThumbnailBuilder.h <==
/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef THUMBNAILBUILDER_H
#define THUMBNAILBUILDER_H

#include <QList>
#include <QProgressDialog>
#include <QImage>
#include "ImageManager/ImageClient.h"
#include "DB/ImageInfoPtr.h"
#include "enums.h"

namespace MainWindow { class StatusBar; }
namespace MainWindow { class Window; }

class QTimer;

namespace ImageManager
{

class ThumbnailBuilder :public QObject, public ImageManager::ImageClient {
    Q_OBJECT

public:
    static ThumbnailBuilder* instance();
    void buildAll(ThumbnailBuildStart when );
    void buildMissing();

    OVERRIDE void pixmapLoaded( const QString& fileName, const QSize& size, const QSize& fullSize, int angle, const QImage&, const bool loadedOK);
    OVERRIDE void requestCanceled();

public slots:
    void cancelRequests( );
    void scheduleThumbnailBuild( const QList<DB::ImageInfoPtr>& list, ThumbnailBuildStart when );
    void doThumbnailBuild();

private:
    friend class MainWindow::Window;
    static ThumbnailBuilder* m_instance;
    ThumbnailBuilder( MainWindow::StatusBar* statusBar, QObject* parent );
    MainWindow::StatusBar* m_statusBar;
    int m_count;
    bool m_isBuilding;
    QTimer* m_startBuildTimer;
    QList<DB::ImageInfoPtr> m_thumbnailsToBuild;
};

}

#endif /* THUMBNAILBUILDER_H */

==> kphotoalbum_4.4.orig.tar.bz2: kphotoalbum-4.4/ImageManager/ThumbnailBuilder.h <==
/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef THUMBNAILBUILDER_H
#define THUMBNAILBUILDER_H

#include <QList>
#include <QProgressDialog>
#include <QImage>
#include "ImageManager/ImageClientInterface.h"
#include "DB/ImageInfoPtr.h"
#include "enums.h"
#include <DB/FileNameList.h>

namespace MainWindow { class StatusBar; }
namespace MainWindow { class Window; }

class QTimer;

namespace ImageManager
{

class ThumbnailBuilder :public QObject, public ImageManager::ImageClientInterface {
    Q_OBJECT

public:
    static ThumbnailBuilder* instance();
    void buildAll(ThumbnailBuildStart when );
    void buildMissing();

    OVERRIDE void pixmapLoaded( const DB::FileName& fileName, const QSize& size, const QSize& fullSize, int angle, const QImage&, const bool loadedOK);
    OVERRIDE void requestCanceled();

public slots:
    void cancelRequests( );
    void scheduleThumbnailBuild( const DB::FileNameList& list, ThumbnailBuildStart when );
    void doThumbnailBuild();

private:
    friend class MainWindow::Window;
    static ThumbnailBuilder* m_instance;
    ThumbnailBuilder( MainWindow::StatusBar* statusBar, QObject* parent );
    MainWindow::StatusBar* m_statusBar;
    int m_count;
    bool m_isBuilding;
    QTimer* m_startBuildTimer;
    DB::FileNameList m_thumbnailsToBuild;
};

}

#endif /* THUMBNAILBUILDER_H */

// vi:expandtab:tabstop=4 shiftwidth=4:
